#import <collections.h>

@protocol GridTurtle <Create, Drop, CREATABLE>
- (void) move: (int)distance;
- (void) turn: (int)angle;     /* angle measured in units of pi/2 */
- (void) print;
@end

typedef enum direction { north, east, south, west } direction_t;

externvar id <Symbol>S1;

externvar id <Warning>W1;

externvar id <Error>E1;

#import "grid.xt"
